==> spip_3.2.11.orig.tar.xz: plugins-dist/sites/lang/sites_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'En aspera',
	'articles_meme_auteur' => 'Toui lu article d’aquel autour',
	'articles_off' => 'Bloucat',
	'articles_publie' => 'Publicat',
	'articles_refuse' => 'Suprimat',
	'articles_tous' => 'Toui',
	'aucun_article_syndic' => 'Mìnga article sindicat',
	'avis_echec_syndication_01' => 'La sindicacioun a souhit : lou backend endicat es indechifrable o noun proupausa d’article.',
	'avis_echec_syndication_02' => 'La sindicacioun a souhit : empoussible d’achèdre au backend d’aqueu sit.',
	'avis_site_introuvable' => 'Sit introuvable',
	'avis_site_syndique_probleme' => 'Mèfi : la sindicacioun d’aqueu sit a rescountrat un proublèma ; lou sistèma es pi tempourariamen interout. Verificas l’adressa dóu fichié de sindicacioun d’aqueu sit (<b>@url_syndic@</b>), e prouvas mai una recuperacioun dei infourmacioun.',
	'avis_sites_probleme_syndication' => 'Aquelu sit an rescountrat un proublèma de sindicacioun',
	'avis_sites_syndiques_probleme' => 'Aquelu sit sindicat an pauat un proublèma',

	// B
	'bouton_exporter' => 'Espourtà',
	'bouton_importer' => 'Empourtà',
	'bouton_radio_modere_posteriori' => 'mouderacioun a posteriori',
	'bouton_radio_modere_priori' => 'mouderacioun a priori',
	'bouton_radio_non_syndication' => 'Mìnga de sindicacioun',
	'bouton_radio_syndication' => 'Sindicacioun :',

	// C
	'confirmer_purger_syndication' => 'Sias segur de voulé suprimà toui lu article sindicat dau sit ?',

	// E
	'entree_adresse_fichier_syndication' => 'Adressa dóu fichié de sindicacioun :',
	'entree_adresse_site' => '<b>Adressa dóu sit</b> [Oubligatori]',
	'entree_description_site' => 'Descricioun dóu sit',
	'erreur_fichier_format_inconnu' => 'Lou fourmat dóu fichié @fichier@ es pas supourtat.',
	'erreur_fichier_incorrect' => 'Empoussible de legì lou fichié.',

	// F
	'form_prop_nom_site' => 'Noum dóu sit',

	// I
	'icone_article_syndic' => 'Article sindicat',
	'icone_articles_syndic' => 'Article sindicat',
	'icone_controler_syndication' => 'Publicacioun dei article sindicat',
	'icone_modifier_site' => 'Moudificà aqueu sit',
	'icone_referencer_nouveau_site' => 'Referençà un nouvèu sit',
	'icone_site_reference' => 'Sit referençat',
	'icone_supprimer_article' => 'Suprimà aquel article',
	'icone_supprimer_articles' => 'Suprimà aquelu article',
	'icone_valider_article' => 'Validà aquel article',
	'icone_valider_articles' => 'Validà aquelu article',
	'icone_voir_sites_references' => 'Veire lu sit referençat',
	'info_1_article_syndique' => '1 article sindicat',
	'info_1_site' => '1 sit',
	'info_1_site_importe' => '1 sit es estat empourtat',
	'info_a_valider' => '[da validà]',
	'info_aucun_article_syndique' => 'Mìnga article sindicat',
	'info_aucun_site' => 'Mìnga sit',
	'info_aucun_site_importe' => 'Mìnga sit si pòu estre empourtat',
	'info_bloquer' => 'bloucà',
	'info_bloquer_lien' => 'bloucà aqueu sit',
	'info_derniere_syndication' => 'La darrièra sindicacioun d’aqueu sit es estada efetuada lou',
	'info_liens_syndiques_1' => 'estac sindicat',
	'info_liens_syndiques_2' => 'soun en aspera de validacioun.',
	'info_nb_articles_syndiques' => '@nb@ article sindicat',
	'info_nb_sites' => '@nb@ sit',
	'info_nb_sites_importes' => '@nb@ sit soun estat empourtat',
	'info_nom_site_2' => '<b>Noum dóu sit</b> [Oubligatori]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'proublèma de',
	'info_question_proposer_site' => 'Qu pòu proupausà dei sit referençat ?',
	'info_retablir_lien' => 'restabilì aquel estac',
	'info_site_attente' => 'Sit Web en aspera de validacioun',
	'info_site_propose' => 'Sit proupausat lou :',
	'info_site_reference' => 'Sit referençat en ligna',
	'info_site_refuse' => 'Sit Web refudat',
	'info_site_syndique' => 'Aqueu sit es sindicat…',
	'info_site_valider' => 'Sit da validà',
	'info_sites_referencer' => 'Referençà un sit',
	'info_sites_refuses' => 'Lu sit refudat',
	'info_statut_site_1' => 'Aqueu sit es :',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Proupausat',
	'info_statut_site_4' => 'Ai rementa',
	'info_syndication' => 'sindicacioun :',
	'info_syndication_articles' => 'article',
	'item_bloquer_liens_syndiques' => 'Bloucà lu estac sindicat per validacioun',
	'item_gerer_annuaire_site_web' => 'Gerà un anuàri de sit Web',
	'item_non_bloquer_liens_syndiques' => 'Noun bloucà lu estac que venon de la sindicacioun',
	'item_non_gerer_annuaire_site_web' => 'Desativà l’anuàri de sit Web',
	'item_non_utiliser_syndication' => 'Noun utilisà la sindicacioun automatica',
	'item_utiliser_syndication' => 'Utilisà la sindicacioun automatica',

	// L
	'label_exporter_avec_mots_cles_1' => 'Espourtà lu mot clau souta la forma de tag',
	'label_exporter_id_parent' => 'Espourtà lu sit de la rùbrica',
	'label_exporter_publie_seulement_1' => 'Espourtà basta lu sit publicat',
	'label_fichier_import' => 'Fichié HTML',
	'label_importer_les_tags_1' => 'Empourtà lu tag souta la forma de mot clau',
	'label_importer_statut_publie_1' => 'Publicà automaticamen lu sit',
	'lien_mise_a_jour_syndication' => 'Metre a jou ahura',
	'lien_nouvelle_recuperation' => 'Prouvà mai de recuperà li dounada',
	'lien_purger_syndication' => 'Escassà toui lu article sindicat',

	// N
	'nombre_articles_syndic' => '@nb@ article sindicat',

	// S
	'statut_off' => 'Suprimat',
	'statut_prop' => 'En aspera',
	'statut_publie' => 'Publicat',
	'syndic_choix_moderation' => 'Que faire dei estac venent en prouvenença d’aquèu sit ?',
	'syndic_choix_oublier' => 'Que faire dei estac que soun plus en lou fichié de sindicacioun ?',
	'syndic_choix_resume' => 'D’unu sit difondon lou tèst coumplet dei article. Quoura aquestou es dispounible, vourìas sindicà :',
	'syndic_lien_obsolete' => 'Estac oussoulet',
	'syndic_option_miroir' => 'lu bloucà automaticamen',
	'syndic_option_oubli' => 'lu escassà (après @mois@ mès)',
	'syndic_option_resume_non' => 'lou countengut coumplet dei article (au fourmat HTML)',
	'syndic_option_resume_oui' => 'un simple coumpèndi (au fourmat tèst)',
	'syndic_options' => 'Oupcioun de sindicacioun :',

	// T
	'texte_expliquer_export_bookmarks' => 'Poudès espourtà una lista de sit au fourmat Marca pàgina HTML, e poudès pi l’empourtà en lou vouòstre navigadour o un servici en ligna.',
	'texte_expliquer_import_bookmarks' => 'Poudès empourtà una lista de sit au fourmat Marca pàgina HTML, dau vouòstre navigadour o da un servici en ligna de gestioun dei Marca pàgina.',
	'texte_liens_sites_syndiques' => 'Lu estac que venon dei sit sindicat pouòdon estre bloucat a priòri ; lou reglage aquì souta endica lou reglage predefinit dei sit sindicat après la sieu creacioun. Es pi possible de
desbloucà cada estac individualamen, o de chausì, sit per sit, de bloucà lu estac que venon de tau o tau sit.',
	'texte_messages_publics' => 'Message public dau article :',
	'texte_non_fonction_referencement' => 'Poudès chausì de noun utilisà aquela founcioun automatica, e endicà vi meme lu elemen que tocon aqueu sit...',
	'texte_referencement_automatique' => '<b>Referençamen automatisat d’un sit</b><br />Poudès lèu referençà un sit web en endicant aquì souta l’adressa URL desirada, o l’adressa dóu sieu fichié de sindicacioun. SPIP va cercà automaticamen li infourmacioun que councernon aqueu sit (titre, descricioun...).',
	'texte_referencement_automatique_verifier' => 'Vourguès verificà li infourmacioun fournidi per <tt>@url@</tt> denant de registrà.',
	'texte_syndication' => 'Si pòu recuperà automaticamen, quoura un sit web lou permete,
la lista dei sieu nouvità. Per faire acò, vi cau ativà la sindicacioun. 
	<blockquote><i>D’unu aubergadour noun ativon aquela founciounalità ; en aqueu cas, noun pourès utilisà la sindicacioun de countengut despì lou vouòstre sit.</i></blockquote>',
	'titre_articles_syndiques' => 'Article sindicat titrat d’aqueu sit',
	'titre_dernier_article_syndique' => 'Darrié article sindicat',
	'titre_exporter_bookmarks' => 'Espourtà lu Marca pàgina',
	'titre_importer_bookmarks' => 'Empourtà lu Marca pàgina',
	'titre_importer_exporter_bookmarks' => 'Empourtà e Espourtà dei Marca pàgina',
	'titre_page_sites_tous' => 'Lu sit referençat',
	'titre_referencement_sites' => 'Referençamen de sit e sindicacioun',
	'titre_site_numero' => 'SIT NÙMERO :',
	'titre_sites_proposes' => 'Lu sit proupausà',
	'titre_sites_references_rubrique' => 'Lu sit referençat en aquela rùbrica',
	'titre_sites_syndiques' => 'Lu sit sindicat',
	'titre_sites_tous' => 'Lu sit referençat',
	'titre_syndication' => 'Sindicacioun de sit',
	'tout_voir' => 'Veire toui lu article sindicat',

	// U
	'un_article_syndic' => '1 article sindicat'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// A
	'articles_dispo' => 'En aspera',
	'articles_meme_auteur' => 'Toui lu article d’aquel autour',
	'articles_off' => 'Bloucat',
	'articles_publie' => 'Publicat',
	'articles_refuse' => 'Suprimat',
	'articles_tous' => 'Toui',
	'aucun_article_syndic' => 'Mìnga article sindicat',
	'avis_echec_syndication_01' => 'La sindicacioun a souhit : lou backend endicat es indechifrable o noun proupausa d’article.',
	'avis_echec_syndication_02' => 'La sindicacioun a souhit : empoussible d’achèdre au backend d’aqueu sit.',
	'avis_site_introuvable' => 'Sit introuvable',
	'avis_site_syndique_probleme' => 'Mèfi : la sindicacioun d’aqueu sit a rescountrat un proublèma ; lou sistèma es pi tempourariamen interout. Verificas l’adressa dóu fichié de sindicacioun d’aqueu sit (<b>@url_syndic@</b>), e prouvas mai una recuperacioun dei infourmacioun.',
	'avis_sites_probleme_syndication' => 'Aquelu sit an rescountrat un proublèma de sindicacioun',
	'avis_sites_syndiques_probleme' => 'Aquelu sit sindicat an pauat un proublèma',

	// B
	'bouton_exporter' => 'Espourtà',
	'bouton_importer' => 'Empourtà',
	'bouton_radio_modere_posteriori' => 'mouderacioun a posteriori',
	'bouton_radio_modere_priori' => 'mouderacioun a priori',
	'bouton_radio_non_syndication' => 'Mìnga de sindicacioun',
	'bouton_radio_syndication' => 'Sindicacioun :',

	// C
	'confirmer_purger_syndication' => 'Sias segur de voulé suprimà toui lu article sindicat dau sit ?',

	// E
	'entree_adresse_fichier_syndication' => 'Adressa dóu fichié de sindicacioun :',
	'entree_adresse_site' => '<b>Adressa dóu sit</b> [Oubligatori]',
	'entree_description_site' => 'Descricioun dóu sit',
	'erreur_fichier_format_inconnu' => 'Lou fourmat dóu fichié @fichier@ es pas supourtat.',
	'erreur_fichier_incorrect' => 'Empoussible de legì lou fichié.',

	// F
	'form_prop_nom_site' => 'Noum dóu sit',

	// I
	'icone_article_syndic' => 'Article sindicat',
	'icone_articles_syndic' => 'Article sindicat',
	'icone_controler_syndication' => 'Publicacioun dei article sindicat',
	'icone_modifier_site' => 'Moudificà aqueu sit',
	'icone_referencer_nouveau_site' => 'Referençà un nouvèu sit',
	'icone_site_reference' => 'Sit referençat',
	'icone_supprimer_article' => 'Suprimà aquel article',
	'icone_supprimer_articles' => 'Suprimà aquelu article',
	'icone_valider_article' => 'Validà aquel article',
	'icone_valider_articles' => 'Validà aquelu article',
	'icone_voir_sites_references' => 'Veire lu sit referençat',
	'info_1_article_syndique' => '1 article sindicat',
	'info_1_site' => '1 sit',
	'info_1_site_importe' => '1 sit es estat empourtat',
	'info_a_valider' => '[da validà]',
	'info_aucun_article_syndique' => 'Mìnga article sindicat',
	'info_aucun_site' => 'Mìnga sit',
	'info_aucun_site_importe' => 'Mìnga sit si pòu estre empourtat',
	'info_bloquer' => 'bloucà',
	'info_bloquer_lien' => 'bloucà aqueu sit',
	'info_derniere_syndication' => 'La darrièra sindicacioun d’aqueu sit es estada efetuada lou',
	'info_liens_syndiques_1' => 'estac sindicat',
	'info_liens_syndiques_2' => 'soun en aspera de validacioun.',
	'info_nb_articles_syndiques' => '@nb@ article sindicat',
	'info_nb_sites' => '@nb@ sit',
	'info_nb_sites_importes' => '@nb@ sit soun estat empourtat',
	'info_nom_site_2' => '<b>Noum dóu sit</b> [Oubligatori]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'proublèma de',
	'info_question_proposer_site' => 'Qu pòu proupausà dei sit referençat ?',
	'info_retablir_lien' => 'restabilì aquel estac',
	'info_site_attente' => 'Sit Web en aspera de validacioun',
	'info_site_propose' => 'Sit proupausat lou :',
	'info_site_reference' => 'Sit referençat en ligna',
	'info_site_refuse' => 'Sit Web refudat',
	'info_site_syndique' => 'Aqueu sit es sindicat…',
	'info_site_valider' => 'Sit da validà',
	'info_sites_referencer' => 'Referençà un sit',
	'info_sites_refuses' => 'Lu sit refudat',
	'info_statut_site_1' => 'Aqueu sit es :',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Proupausat',
	'info_statut_site_4' => 'Ai rementa',
	'info_syndication' => 'sindicacioun :',
	'info_syndication_articles' => 'article',
	'item_bloquer_liens_syndiques' => 'Bloucà lu estac sindicat per validacioun',
	'item_gerer_annuaire_site_web' => 'Gerà un anuàri de sit Web',
	'item_non_bloquer_liens_syndiques' => 'Noun bloucà lu estac que venon de la sindicacioun',
	'item_non_gerer_annuaire_site_web' => 'Desativà l’anuàri de sit Web',
	'item_non_utiliser_syndication' => 'Noun utilisà la sindicacioun automatica',
	'item_utiliser_syndication' => 'Utilisà la sindicacioun automatica',

	// L
	'label_exporter_avec_mots_cles_1' => 'Espourtà lu mot clau souta la forma de tag',
	'label_exporter_id_parent' => 'Espourtà lu sit de la rùbrica',
	'label_exporter_publie_seulement_1' => 'Espourtà basta lu sit publicat',
	'label_fichier_import' => 'Fichié HTML',
	'label_importer_les_tags_1' => 'Empourtà lu tag souta la forma de mot clau',
	'label_importer_statut_publie_1' => 'Publicà automaticamen lu sit',
	'lien_mise_a_jour_syndication' => 'Metre a jou ahura',
	'lien_nouvelle_recuperation' => 'Prouvà mai de recuperà li dounada',
	'lien_purger_syndication' => 'Escassà toui lu article sindicat',

	// N
	'nombre_articles_syndic' => '@nb@ article sindicat',

	// S
	'statut_off' => 'Suprimat',
	'statut_prop' => 'En aspera',
	'statut_publie' => 'Publicat',
	'syndic_choix_moderation' => 'Que faire dei estac venent en prouvenença d’aquèu sit ?',
	'syndic_choix_oublier' => 'Que faire dei estac que soun plus en lou fichié de sindicacioun ?',
	'syndic_choix_resume' => 'D’unu sit difondon lou tèst coumplet dei article. Quoura aquestou es dispounible, vourìas sindicà :',
	'syndic_lien_obsolete' => 'Estac oussoulet',
	'syndic_option_miroir' => 'lu bloucà automaticamen',
	'syndic_option_oubli' => 'lu escassà (après @mois@ mès)',
	'syndic_option_resume_non' => 'lou countengut coumplet dei article (au fourmat HTML)',
	'syndic_option_resume_oui' => 'un simple coumpèndi (au fourmat tèst)',
	'syndic_options' => 'Oupcioun de sindicacioun :',

	// T
	'texte_expliquer_export_bookmarks' => 'Poudès espourtà una lista de sit au fourmat Marca pàgina HTML, e poudès pi l’empourtà en lou vouòstre navigadour o un servici en ligna.',
	'texte_expliquer_import_bookmarks' => 'Poudès empourtà una lista de sit au fourmat Marca pàgina HTML, dau vouòstre navigadour o da un servici en ligna de gestioun dei Marca pàgina.',
	'texte_liens_sites_syndiques' => 'Lu estac que venon dei sit sindicat pouòdon estre bloucat a priòri ; lou reglage aquì souta endica lou reglage predefinit dei sit sindicat après la sieu creacioun. Es pi possible de
desbloucà cada estac individualamen, o de chausì, sit per sit, de bloucà lu estac que venon de tau o tau sit.',
	'texte_messages_publics' => 'Message public dau article :',
	'texte_non_fonction_referencement' => 'Poudès chausì de noun utilisà aquela founcioun automatica, e endicà vi meme lu elemen que tocon aqueu sit...',
	'texte_referencement_automatique' => '<b>Referençamen automatisat d’un sit</b><br />Poudès lèu referençà un sit web en endicant aquì souta l’adressa URL desirada, o l’adressa dóu sieu fichié de sindicacioun. SPIP va cercà automaticamen li infourmacioun que councernon aqueu sit (titre, descricioun...).',
	'texte_referencement_automatique_verifier' => 'Vourguès verificà li infourmacioun fournidi per <tt>@url@</tt> denant de registrà.',
	'texte_syndication' => 'Si pòu recuperà automaticamen, quoura un sit web lou permete,
la lista dei sieu nouvità. Per faire acò, vi cau ativà la sindicacioun. 
	<blockquote><i>D’unu aubergadour noun ativon aquela founciounalità ; en aqueu cas, noun pourès utilisà la sindicacioun de countengut despì lou vouòstre sit.</i></blockquote>',
	'titre_articles_syndiques' => 'Article sindicat titrat d’aqueu sit',
	'titre_dernier_article_syndique' => 'Darrié article sindicat',
	'titre_exporter_bookmarks' => 'Espourtà lu Marca pàgina',
	'titre_importer_bookmarks' => 'Empourtà lu Marca pàgina',
	'titre_importer_exporter_bookmarks' => 'Empourtà e Espourtà dei Marca pàgina',
	'titre_page_sites_tous' => 'Lu sit referençat',
	'titre_referencement_sites' => 'Referençamen de sit e sindicacioun',
	'titre_site_numero' => 'SIT NÙMERO :',
	'titre_sites_proposes' => 'Lu sit proupausà',
	'titre_sites_references_rubrique' => 'Lu sit referençat en aquela rùbrica',
	'titre_sites_syndiques' => 'Lu sit sindicat',
	'titre_sites_tous' => 'Lu sit referençat',
	'titre_syndication' => 'Sindicacioun de sit',
	'tout_voir' => 'Veire toui lu article sindicat',

	// U
	'un_article_syndic' => '1 article sindicat',
];
